@@ -1,26 +1,30 @@
 #!/usr/bin/env python3
 
 import logging
-import sys
 import os.path
-import json # Language
-import tempfile # Cache
-import datetime # Cache
-import urllib.request # Connect
-import urllib.parse # Location
+import json  # Language
+import tempfile  # Cache
+import datetime  # Cache
+import urllib.request  # Connect
+import urllib.parse  # Location
 import xmltodict
 
+log = logging.getLogger(__name__)
+
+
 class YrObject:
 
-    script_directory = os.path.dirname(os.path.abspath(__file__)) # directory of the script
+    script_directory = os.path.dirname(os.path.abspath(__file__))  # directory of the script
     encoding = 'utf-8'
 
+
 class YrException(Exception):
 
     def __init__(self, message):
-        logging.error(message)
+        log.error(message)
         raise
 
+
 class Language(YrObject):
 
     directory = 'languages'
@@ -33,20 +37,21 @@ class Language(YrObject):
             self.script_directory,
             self.directory,
             '{language_name}.{extension}'.format(
-                language_name = self.language_name,
-                extension = self.extension,
-            ), # basename of filename
+                language_name=self.language_name,
+                extension=self.extension,
+            ),  # basename of filename
         )
         self.dictionary = self.get_dictionary()
 
     def get_dictionary(self):
         try:
-            logging.info('read language dictionary: {}'.format(self.filename))
+            log.info('read language dictionary: {}'.format(self.filename))
             with open(self.filename, mode='r', encoding=self.encoding) as f:
                 return json.load(f)
         except Exception as e:
             raise YrException(e)
 
+
 class Location(YrObject):
 
     base_url = 'http://www.yr.no/'
@@ -58,7 +63,7 @@ class Location(YrObject):
         self.location_name = location_name
         self.language = language if isinstance(language, Language) else Language()
 
-        if forecast_link in self.forecast_links: # must be valid forecast_link
+        if forecast_link in self.forecast_links:  # must be valid forecast_link
             self.forecast_link = self.language.dictionary[forecast_link]
         else:
             self.forecast_link = self.default_forecast_link
@@ -68,11 +73,11 @@ class Location(YrObject):
 
     def get_url(self):
         return '{base_url}{place}/{location_name}/{forecast_link}.{extension}'.format(
-            base_url = self.base_url,
-            place = self.language.dictionary['place'],
-            location_name = urllib.parse.quote(self.location_name),
-            forecast_link = self.forecast_link,
-            extension = self.extension,
+            base_url=self.base_url,
+            place=self.language.dictionary['place'],
+            location_name=urllib.parse.quote(self.location_name),
+            forecast_link=self.forecast_link,
+            extension=self.extension,
         )
 
     def get_hash(self):
@@ -81,10 +86,12 @@ class Location(YrObject):
             forecast_link=self.forecast_link,
         )
 
-class API_Locationforecast(YrObject):
-    """Class to use the API of yr.no"""
 
-    base_url = 'http://api.yr.no/weatherapi/locationforecast/1.9/?'
+class API_Locationforecast(YrObject):
+
+    """Class to use the API of api.met.no"""
+
+    base_url = 'https://api.met.no/weatherapi/locationforecast/1.9/?'
     forecast_link = 'locationforecast'
 
     def __init__(self, lat, lon, msl=0, language=False):
@@ -96,7 +103,7 @@ class API_Locationforecast(YrObject):
         """
         self.coordinates = dict(lat=lat, lon=lon, msl=msl)
         self.location_name = 'lat={lat};lon={lon};msl={msl}'.format(**self.coordinates)
-        #self.language = language if isinstance(language, Language) else Language()
+        # self.language = language if isinstance(language, Language) else Language()
         self.url = self.get_url()
         self.hash = self.get_hash()
 
@@ -114,7 +121,9 @@ class API_Locationforecast(YrObject):
             forecast_link=self.forecast_link,
         )
 
-class LocationXYZ(API_Locationforecast): # ~> Deprecated!!!
+
+class LocationXYZ(API_Locationforecast):  # ~> Deprecated!!!
+
     """Class to use the API of yr.no"""
 
     def __init__(self, x, y, z=0, language=False):
@@ -126,6 +135,7 @@ class LocationXYZ(API_Locationforecast): # ~> Deprecated!!!
         """
         super().__init__(y, x, z, language)
 
+
 class Connect(YrObject):
 
     def __init__(self, location):
@@ -133,13 +143,13 @@ class Connect(YrObject):
 
     def read(self):
         try:
-            logging.info('weatherdata request: {}, forecast-link: {}'.format(
+            log.info('weatherdata request: {}, forecast-link: {}'.format(
                 self.location.location_name,
                 self.location.forecast_link,
             ))
             cache = Cache(self.location)
             if not cache.exists() or not cache.is_fresh():
-                logging.info('read online: {}'.format(self.location.url))
+                log.info('read online: {}'.format(self.location.url))
                 response = urllib.request.urlopen(self.location.url)
                 if response.status != 200:
                     raise
@@ -151,11 +161,12 @@ class Connect(YrObject):
         except Exception as e:
             raise YrException(e)
 
+
 class Cache(YrObject):
 
     directory = tempfile.gettempdir()
     extension = 'xml'
-    timeout = 15 # cache timeout in minutes
+    timeout = 15  # cache timeout in minutes
 
     def __init__(self, location):
         self.location = location
@@ -164,38 +175,50 @@ class Cache(YrObject):
             '{location_hash}.{extension}'.format(
                 location_hash=self.location.hash,
                 extension=self.extension,
-            ), # basename of filename
+            ),  # basename of filename
         )
 
     def dump(self, data):
-        logging.info('writing cachefile: {}'.format(self.filename))
+        log.info('writing cachefile: {}'.format(self.filename))
         with open(self.filename, mode='w', encoding=self.encoding) as f:
             f.write(data)
 
     def valid_until_timestamp_from_file(self):
         xmldata = self.load()
         d = xmltodict.parse(xmldata)
-        next_update = d['weatherdata']['meta']['nextupdate']
-        valid_until = datetime.datetime.strptime(next_update,"%Y-%m-%dT%H:%M:%S")
-        logging.info('Cache is valid until {}'.format(valid_until))
+        meta = d['weatherdata']['meta']
+        if isinstance(self.location, API_Locationforecast):
+            if isinstance(meta['model'], dict):
+                next_update = meta['model']['@nextrun']
+            elif isinstance(meta['model'], list):
+                next_update = meta['model'][0]['@nextrun']
+            else:
+                return False
+            date_format = '%Y-%m-%dT%H:%M:%SZ'
+        else:
+            next_update = meta['nextupdate']
+            date_format = '%Y-%m-%dT%H:%M:%S'
+        valid_until = datetime.datetime.strptime(next_update, date_format)
+        # hotfix API_Locationforecast ++ @nextrun <<<
+        log.info('Cache is valid until {}'.format(valid_until))
         return valid_until
 
     def is_fresh(self):
-        logging.info('Now is {}'.format(datetime.datetime.now()))
+        log.info('Now is {}'.format(datetime.datetime.now()))
         return datetime.datetime.now() <= self.valid_until_timestamp_from_file()
 
     def exists(self):
         return os.path.isfile(self.filename)
 
     def load(self):
-        logging.info('read from cachefile: {}'.format(self.filename))
+        log.info('read from cachefile: {}'.format(self.filename))
         with open(self.filename, mode='r', encoding=self.encoding) as f:
             return f.read()
 
     def remove(self):
         if os.path.isfile(self.filename):
             os.remove(self.filename)
-            logging.info('removed cachefile: {}'.format(self.filename))
+            log.info('removed cachefile: {}'.format(self.filename))
 
 if __name__ == '__main__':
     logging.basicConfig(level=logging.DEBUG)
@@ -206,14 +229,14 @@ if __name__ == '__main__':
         forecast_link='forecast',
         language=Language(language_name='en'),
     )).read()
-    #print(weatherdata)
+    # print(weatherdata)
 
     weatherdata = Connect(Location(
         location_name='Czech_Republic/Prague/Prague',
         forecast_link='forecast_hour_by_hour',
         language=Language(language_name='en'),
     )).read()
-    #print(weatherdata)
+    # print(weatherdata)
 
     weatherdata = Connect(API_Locationforecast(
         50.0596696,
@@ -221,6 +244,6 @@ if __name__ == '__main__':
         11,
         language=Language(language_name='en'),
     )).read()
-    #print(weatherdata)
+    # print(weatherdata)
 
     logging.info('stopping __main__')
